@@ -1,30 +1,25 @@
 /*
- * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ * Copyright (C) 2015 Stuart Howarth <showarth@marxoft.co.uk>
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU Lesser General Public License,
- * version 3, as published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
  *
- * This program is distributed in the hope it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
- * more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef STREAMEXTRACTOR_H
 #define STREAMEXTRACTOR_H
 
 #include <QNetworkReply>
-#if QT_VERSION >= 0x050000
-#include <qqml.h>
-#else
-#include <qdeclarative.h>
-#endif
 
+class QNetworkAccessManager;
 class QUrl;
 
 class StreamExtractor : public QObject
@@ -57,21 +52,25 @@ public:
     QNetworkReply::NetworkError error() const;
     QString errorString() const;
     
-public slots:
-    void getStreamUrl(const QString &url);
+public Q_SLOTS:
+    void getStreamUrl(const QUrl &url);
     void cancel();
 
-private:
-    void setStatus(Status status);
+private:    
+    void setStatus(Status s);
+    
     void retry(const QUrl &url);
+    
+    QNetworkAccessManager* networkAccessManager();
 
-private slots:
+private Q_SLOTS:
     void parseResponse();
 
-signals:
-    void statusChanged();
+Q_SIGNALS:
+    void statusChanged(StreamExtractor::Status status);
 
 private:
+    QNetworkAccessManager *m_nam;
     QNetworkReply *m_reply;
     
     Status m_status;
@@ -81,6 +80,4 @@ private:
     QString m_result;
 };
 
-QML_DECLARE_TYPE(StreamExtractor)
-
 #endif
